Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(121)

Unified Diff: src/ast/ast-numbering.h

Issue 2618553004: [compiler] Collect eager inner functions for compilation during renumbering. (Closed)
Patch Set: Remove unused variable Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/ast/ast-numbering.h
diff --git a/src/ast/ast-numbering.h b/src/ast/ast-numbering.h
index 73278950cd220919abcb200fd1fb689e0fc3991f..31bd0872de641e171f6f599cdd405339e2b91c36 100644
--- a/src/ast/ast-numbering.h
+++ b/src/ast/ast-numbering.h
@@ -12,11 +12,15 @@ namespace internal {
class FunctionLiteral;
class Isolate;
class Zone;
+template <typename T>
+class ZoneVector;
namespace AstNumbering {
// Assign type feedback IDs, bailout IDs, and generator yield IDs to an AST node
-// tree; perform catch prediction for TryStatements.
-bool Renumber(Isolate* isolate, Zone* zone, FunctionLiteral* function);
+// tree; perform catch prediction for TryStatements. Adds any eager inner
+// literal functions found into |eager_inner_functions|.
+bool Renumber(Isolate* isolate, Zone* zone, FunctionLiteral* function,
+ ZoneVector<FunctionLiteral*>* eager_inner_functions);
marja 2017/01/05 19:25:22 I was thinking about the ZoneVector usage here...
rmcilroy 2017/01/06 17:08:14 Yes good point, I'm not sure we have a good defaul
rmcilroy 2017/01/09 16:50:10 Done.
}
// Some details on yield IDs
« no previous file with comments | « src/asmjs/asm-wasm-builder.cc ('k') | src/ast/ast-numbering.cc » ('j') | src/compiler.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698